# Changelog

## [0.2.9a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.9a1) (2025-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.8...0.2.9a1)

**Merged pull requests:**

- fix: compat with opm 1.X.X [\#59](https://github.com/OpenVoiceOS/ovos-PHAL/pull/59) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
